pub struct PathItemArgs {
pub key: FieldKey,
pub path: PathBuf,
pub parent: Option<FieldKey>,
pub permission: Permission,
pub owner: Owner,
pub path_type: PathType,
pub deferred: bool,
pub metadata: HashMap<String, MetadataValue>,
}Expand description
Input path item arguments
This struct is used in the ConfigBuilder::add_path_item as input arguments.
Fields
key: FieldKeyThe name of the field.
path: PathBufThe path part that may or may not contain placeholders. For example, path/to/{item}. It
is recommended that all path parts are always relative, and to have the root of the path
defined as a placeholder.
parent: Option<FieldKey>The parent path item’s field key.
permission: PermissionThe permission of the path and all child paths unless explicitly set.
owner: OwnerThe owner of the path and all child paths unless explicitly set.
path_type: PathTypeThe path of the path and all child paths unless explicitly set.
deferred: boolWhether the path is deferred or not. If a path is deferred, then the
create_workspace will not resolve the path unless a subpath is
resolvable. For example, if the path path/to/{thing} is marked as deferred, then even if
the field thing is available when resolving the path, the path will not be resolved.
However, if the path has a non-defferred subpath that expands the current path to
path/to/{thing}/some/{subthing}, and both thing and subthing are valid, then the path
will be resolved.
metadata: HashMap<String, MetadataValue>Extra metadata for the arguments that may be useful, such as marking a path as belonging to a specific user.